@@ -37,12 +37,105 @@
 
 QMutex functiondefmutex;
 
+stringVector IdentifierList(tree t) {
+  stringVector retval;
+  for (unsigned index=0;index<t.numchildren();index++) {
+    if (t.child(index).is('&'))
+      retval.push_back("&" + t.child(index).first().text());
+    else
+      retval.push_back(t.child(index).text());
+  }
+  return retval;
+}
+
+void VariableReferencesList(const tree & t, stringVector& idents) {
+  if (t.is(TOK_NEST_FUNC)) return;
+  if (t.is(TOK_VARIABLE)) {
+    bool exists = false;
+    for (int i=0;(i<idents.size());i++) {
+      exists = (idents[i] == t.first().text());
+      if (exists) break;
+    }
+    if (!exists)
+      idents.push_back(t.first().text());
+  }
+  for (int i=0;i<t.numchildren();i++)
+    VariableReferencesList(t.child(i),idents);
+}
+
+AnonymousFunctionDef::AnonymousFunctionDef() {
+}
+
+AnonymousFunctionDef::~AnonymousFunctionDef() {
+}
+
+int AnonymousFunctionDef::inputArgCount() {
+  return arguments.size();
+}
+
+int AnonymousFunctionDef::outputArgCount() {
+  return -1;
+}
+
+ArrayVector AnonymousFunctionDef::evaluateFunction(Interpreter *eval, ArrayVector& inputs, int nargout) {
+  ArrayVector outputs;
+  if (!code.valid()) return outputs;
+  Context * context = eval->getContext();
+  context->pushScope("anonymous");
+  eval->pushDebug("anonymous","anonymous");
+  stringVector workspaceVars(workspace.getCompletions(""));
+  for (int i=0;i<workspaceVars.size();i++)
+    context->insertVariableLocally(workspaceVars[i],*workspace.findSymbol(workspaceVars[i]));
+  int minCount = (inputs.size() < arguments.size()) ? inputs.size() : arguments.size();
+  for (int i=0;i<minCount;i++)
+    context->insertVariableLocally(arguments[i],inputs[i]);
+  try {
+    try {
+      eval->multiexpr(code,outputs);
+    } catch (InterpreterBreakException& e) {
+    } catch (InterpreterContinueException& e) {
+    } catch (InterpreterReturnException& e) {
+    }
+    context->popScope();
+    eval->popDebug();
+  } catch (Exception& e) {
+    context->popScope();
+    eval->popDebug();
+    throw;
+  } catch (InterpreterRetallException& e) {
+    context->popScope();
+    eval->popDebug();
+    throw;    
+  }
+  return outputs;
+}
+
+void AnonymousFunctionDef::initialize(const tree &t, Interpreter *eval) {
+  name = t.text();
+  arguments = IdentifierList(t.first());
+  code = t.second();
+  scriptFlag = false;
+  temporaryFlag = false;
+  graphicsFunction = false;
+  stringVector vars;
+  VariableReferencesList(t.second(),vars);
+  for (int i=0;i<vars.size();i++) {
+    ArrayReference ptr(eval->getContext()->lookupVariable(vars[i]));
+    if (ptr.valid()) {
+      //      cout << "Captured VAR: " << vars[i] << "\r\n";
+      workspace.insertSymbol(vars[i],*ptr);
+    }
+  }
+}
+
 MFunctionDef::MFunctionDef() {
   functionCompiled = false;
   timeStamp = 0;
-  //  allCode = NULL;
   localFunction = false;
   pcodeFunction = false;
+#warning - check pcode
+  nestedFunction = false;
+  capturedFunction = false;
 }
 
 MFunctionDef::~MFunctionDef() {
@@ -88,6 +181,51 @@ void MFunctionDef::printMe(Interpreter*eval) {
   code.print();
 }
 
+
+#warning - This design causes an unneccesary copy - should use readonly pass first
+void CaptureFunctionPointer(FuncPtr &val, Interpreter *walker, 
+			    MFunctionDef *parent, ScopePtr &workspace) {
+  if (val->type() == FM_M_FUNCTION) {
+    MFunctionDef* mptr = (MFunctionDef*) val;
+    if (mptr->nestedFunction && !mptr->capturedFunction) {
+      MFunctionDef* optr = new MFunctionDef;
+      (*optr) = (*mptr);
+      Context* context = walker->getContext();
+      string myScope = context->scopeName();
+      context->bypassScope(1);
+      string parentScope = context->scopeName();
+      context->restoreScope(1);
+      if (!Scope::nests(parentScope,myScope)) {
+	// Now capture the variables in our current scope
+	for (int i=0;i<optr->variablesAccessed.size();i++) {
+	  ArrayReference ptr(context->lookupVariable(optr->variablesAccessed[i]));
+	  if (ptr.valid()) {
+	    if (!workspace)
+	      workspace = new Scope("captured",false);
+	    workspace->insertVariable(optr->variablesAccessed[i],*ptr);
+	  }
+	}
+	optr->workspace = workspace;
+	optr->capturedFunction = true;
+      }
+      val = optr;
+    }
+  }
+}
+
+void CaptureFunctionPointers(ArrayVector& outputs, Interpreter *walker, 
+			     MFunctionDef *parent) {
+  ScopePtr workspace = NULL;
+  // First check for any 
+  for (int i=0;i<outputs.size();i++) {
+    if (outputs[i].dataClass() == FM_FUNCPTR_ARRAY) {
+      FuncPtr *dp = (FuncPtr*) outputs[i].getReadWriteDataPointer();
+      for (int j=0;j<outputs[i].getLength();j++)
+	CaptureFunctionPointer(dp[j],walker,parent,workspace);
+    }
+  }
+}
+
 ArrayVector MFunctionDef::evaluateFunction(Interpreter *walker, 
 					   ArrayVector& inputs, 
 					   int nargout) {
@@ -98,7 +236,14 @@ ArrayVector MFunctionDef::evaluateFunction(Interpreter *walker,
     
   if (!code.valid()) return outputs;
   context = walker->getContext();
-  context->pushScope(name);
+  context->pushScope(name,nestedFunction);
+  context->setVariablesAccessed(variablesAccessed);
+  context->setLocalVariablesList(returnVals);
+  if (capturedFunction && workspace) {
+    stringVector workspaceVars(workspace->getCompletions(""));
+    for (int i=0;i<workspaceVars.size();i++)
+      context->insertVariableLocally(workspaceVars[i],*workspace->lookupVariable(workspaceVars[i]));
+  }
   walker->pushDebug(fileName,name);
   // When the function is called, the number of inputs is
   // at sometimes less than the number of arguments requested.
@@ -242,15 +387,38 @@ ArrayVector MFunctionDef::evaluateFunction(Interpreter *walker,
       if (ptr)
 	inputs[i] = *ptr;
     }
+    // Check the outputs for function pointers
+    CaptureFunctionPointers(outputs,walker,this);
+    if (capturedFunction && workspace) {
+      stringVector workspaceVars(workspace->getCompletions(""));
+      for (int i=0;i<workspaceVars.size();i++) {
+	Array *ptr = context->lookupVariableLocally(workspaceVars[i]);
+	workspace->insertVariable(workspaceVars[i],*ptr);
+      }
+    }
     context->popScope();
     walker->popDebug();
     return outputs;
   } catch (Exception& e) {
+    if (capturedFunction && workspace) {
+      stringVector workspaceVars(workspace->getCompletions(""));
+      for (int i=0;i<workspaceVars.size();i++) {
+	Array *ptr = context->lookupVariableLocally(workspaceVars[i]);
+	workspace->insertVariable(workspaceVars[i],*ptr);
+      }
+    }
     context->popScope();
     walker->popDebug();
     throw;
   }
   catch (InterpreterRetallException& e) {
+    if (capturedFunction && workspace) {
+      stringVector workspaceVars(workspace->getCompletions(""));
+      for (int i=0;i<workspaceVars.size();i++) {
+	Array *ptr = context->lookupVariableLocally(workspaceVars[i]);
+	workspace->insertVariable(workspaceVars[i],*ptr);
+      }
+    }
     context->popScope();
     walker->popDebug();
     throw;
@@ -272,16 +440,6 @@ static string ReadFileIntoString(FILE *fp) {
   return retval;
 }
 
-stringVector IdentifierList(tree t) {
-  stringVector retval;
-  for (unsigned index=0;index<t.numchildren();index++) {
-    if (t.child(index).is('&'))
-      retval.push_back("&" + t.child(index).first().text());
-    else
-      retval.push_back(t.child(index).text());
-  }
-  return retval;
-}
 
 //MFunctionDef* ConvertParseTreeToMFunctionDef(tree t, string fileName) {
 //  MFunctionDef *fp = new MFunctionDef;
@@ -310,10 +468,30 @@ stringVector IdentifierList(tree t) {
 //  return last;
 //}
 
+void RegisterNested(const tree &t, Interpreter *m_eval, MFunctionDef *parent) {
+  if (t.is(TOK_NEST_FUNC)) {
+    MFunctionDef *fp = new MFunctionDef;
+    fp->localFunction = parent->localFunction;
+    fp->nestedFunction = true;
+    fp->returnVals = IdentifierList(t.first());
+    fp->name = parent->name + "/" + t.second().text();
+    fp->arguments = IdentifierList(t.child(2));
+    fp->code = t.child(3);
+    VariableReferencesList(fp->code,fp->variablesAccessed);
+    fp->fileName = parent->fileName;
+    // Register any nested functions for the local functions
+    m_eval->getContext()->insertFunction(fp,false);
+    RegisterNested(fp->code,m_eval,fp);
+  } else
+    for (int i=0;i<t.numchildren();i++)
+      RegisterNested(t.child(i),m_eval,parent);
+}
+
 // Compile the function...
 bool MFunctionDef::updateCode(Interpreter *m_eval) {
   if (localFunction) return false;
   if (pcodeFunction) return false;
+  if (nestedFunction) return false;
   // First, stat the file to get its time stamp
   struct stat filestat;
   stat(fileName.c_str(),&filestat);
@@ -358,7 +536,6 @@ bool MFunctionDef::updateCode(Interpreter *m_eval) {
       Parser P(S);
       tree pcode = P.Process();
       fclose(fp);
-      allCode = pcode;
       if (pcode.is(TOK_FUNCTION_DEFS)) {
 	scriptFlag = false;
 	// Get the main function..
@@ -369,6 +546,9 @@ bool MFunctionDef::updateCode(Interpreter *m_eval) {
 	//	name = MainFuncCode.second().text();
 	arguments = IdentifierList(MainFuncCode.child(2));
 	code = MainFuncCode.child(3);
+	VariableReferencesList(code,variablesAccessed);
+	// Register any nested functions
+	RegisterNested(code,m_eval,this);
 	localFunction = false;
 	// Process the local functions
 	for (int index = 1;index < pcode.numchildren();index++) {
@@ -376,11 +556,18 @@ bool MFunctionDef::updateCode(Interpreter *m_eval) {
 	  MFunctionDef *fp = new MFunctionDef;
 	  fp->localFunction = true;
 	  fp->returnVals = IdentifierList(LocalFuncCode.first());
-	  fp->name = fileName + ":Local:" + LocalFuncCode.second().text();
+	  fp->name = name + "/" + LocalFuncCode.second().text();
 	  fp->arguments = IdentifierList(LocalFuncCode.child(2));
 	  fp->code = LocalFuncCode.child(3);
+	  VariableReferencesList(fp->code,fp->variablesAccessed);
 	  fp->fileName = fileName;
-	  m_eval->getContext()->insertFunction(fp,temporaryFlag);
+	  // Register any nested functions for the local functions
+	  // local functions are not marked as temporary.  This yields
+	  // clutter in the name space, but solves the troublesome
+	  // issue of local functions being flushed by the CD command.
+	  m_eval->getContext()->insertFunction(fp,false);
+	  //	  qDebug() << "Registering " << QString::fromStdString(fp->name);
+	  RegisterNested(fp->code,m_eval,this);
 	}
 	functionCompiled = true;
       } else {
@@ -412,6 +599,9 @@ bool StatementTypeNode(tree t) {
 // 
 void TreeLine(tree t, unsigned &bestLine, unsigned lineTarget) {
   if (!t.valid()) return;
+  // Nested functions are tracked separately - so that we do not
+  // check them for line numbers
+  if (t.is(TOK_NEST_FUNC)) return;
   if (StatementTypeNode(t)) {
     unsigned myLine = (t.context() & 0xffff);
     if ((myLine >= lineTarget) && (myLine < bestLine))
@@ -421,39 +611,17 @@ void TreeLine(tree t, unsigned &bestLine, unsigned lineTarget) {
     TreeLine(t.child(i),bestLine,lineTarget);
 }
 
-bool SetTreeBreakPoint(tree t, int lineNumber, bool enable) {
-  if (!t.valid()) return false;
-  if (StatementTypeNode(t)) {
-    if ((t.context() & 0xffff) == lineNumber) {
-      t.setBPflag(enable);
-      return true;
-    }
-  }
-  for (int i=0;i<t.numchildren();i++)
-    if (SetTreeBreakPoint(t.child(i),lineNumber,enable)) return true;
-  return false;
-}
-
-
 // Find the closest line number to the requested 
 unsigned MFunctionDef::ClosestLine(unsigned line) {
   unsigned bestline;
   bestline = 1000000000;
-  TreeLine(allCode,bestline,line);
+  TreeLine(code,bestline,line);
   if (bestline == 1000000000)
     throw Exception(string("Unable to find a line close to ") + 
 		    line + string(" in routine ") + name);
   return bestline;
 }
 
-void MFunctionDef::SetBreakpoint(int bpline, bool enable) {
-  //  qDebug() << "Set bp called for line " << bpline << " enable is " << enable << " for function :" << QString::fromStdString(name) << "\r\n";
-  if (!SetTreeBreakPoint(allCode,bpline,enable)) 
-    throw Exception(string("Unable to modify a breakpoint at line ") + 
-		    bpline + string(" of routine ") + name);
-  //  allCode.print();
-}
-
 void FreezeMFunction(MFunctionDef *fptr, Serialize *s) {
   s->putString(fptr->name.c_str());
   s->putString(fptr->fileName.c_str());
@@ -462,8 +630,12 @@ void FreezeMFunction(MFunctionDef *fptr, Serialize *s) {
   s->putStringVector(fptr->returnVals);
   s->putBool(fptr->functionCompiled);
   s->putBool(fptr->localFunction);
+  s->putBool(fptr->nestedFunction);
+  s->putBool(fptr->capturedFunction);
   s->putStringVector(fptr->helpText);
-  FreezeTree(fptr->allCode,s);
+  s->putStringVector(fptr->variablesAccessed);
+  FreezeScope(fptr->workspace,s);
+  FreezeTree(fptr->code,s);
 }
 
 MFunctionDef* ThawMFunction(Serialize *s) {
@@ -475,16 +647,12 @@ MFunctionDef* ThawMFunction(Serialize *s) {
   t->returnVals = s->getStringVector();
   t->functionCompiled = s->getBool();
   t->localFunction = s->getBool();
+  t->nestedFunction = s->getBool();
+  t->capturedFunction = s->getBool();
   t->helpText = s->getStringVector();
-  t->allCode = ThawTree(s);
-  if (t->allCode.is(TOK_FUNCTION_DEFS)) {
-    tree MainFuncCode = t->allCode.first();
-    t->code = MainFuncCode.child(3);
-  } else {
-    t->scriptFlag = true;
-    t->functionCompiled = true;
-    t->code = t->allCode.first();
-  }
+  t->variablesAccessed = s->getStringVector();
+  t->workspace = ThawScope(s);
+  t->code = ThawTree(s);
   return t;
 }
 
@@ -672,8 +840,15 @@ ArrayVector ImportedFunctionDef::evaluateFunction(Interpreter *walker,
     context->pushScope("temp");
     walker->pushDebug(name,"bounds check");
     try {
-      for (i=0;i<inputs.size();i++)
-	context->insertVariableLocally(arguments[i],inputs[i]);
+      for (i=0;i<inputs.size();i++) {
+	if (arguments[i][0] != '&') {
+	  context->insertVariableLocally(arguments[i],inputs[i]);
+	} else {
+	  string nme(arguments[i]);
+	  nme.erase(nme.begin());
+	  context->insertVariableLocally(nme,inputs[i]);
+	}
+      }
       /*
        * Next, evaluate each size check expression
        */
