@@ -37,6 +37,7 @@
 #include "HandleList.hpp"
 #include "HandleSurface.hpp"
 #include "HandleWindow.hpp"
+#include "HandleContour.hpp"
 #include "HandleUIControl.hpp"
 #include "QTRenderEngine.hpp"
 #include "Interpreter.hpp"
@@ -170,10 +171,15 @@ bool AnyDirty(bool issueUpdates) {
   return retval;
 }
 
+static bool in_DoDrawNow = false;
+
 void DoDrawNow() {
+  if (in_DoDrawNow) return;
+  in_DoDrawNow = true;
   if (AnyDirty(true))
     while (AnyDirty(false))
       qApp->processEvents();
+  in_DoDrawNow = false;
 }
 
 ArrayVector DrawNowFunction(int nargout, const ArrayVector& arg) {
@@ -217,15 +223,25 @@ void FreeHandleObject(unsigned handle) {
 //@Module FIGURE Figure Window Select and Create Function
 //@@Section HANDLE
 //@@Usage
-//Changes the active figure window to the specified handle 
-//(or figure number).  The general syntax for its use is 
+//Changes the active figure window to the specified figure
+//number.  The general syntax for its use is 
 //@[
-//  figure(handle)
+//  figure(number)
 //@]
-//where @|handle| is the handle to use. If the figure window 
-//corresponding to @|handle| does not already exist, a new 
-//window with this handle number is created.  If it does exist
+//where @|number| is the figure number to use. If the figure window 
+//corresponding to @|number| does not already exist, a new 
+//window with this number is created.  If it does exist
 //then it is brought to the forefront and made active.
+//You can use @|gcf| to obtain the number of the current figure.
+//
+//Note that the figure number is also the handle for the figure.
+//While for most graphical objects (e.g., axes, lines, images), the
+//handles are large integers, for figures, the handle is the same
+//as the figure number.  This means that the figure number can be
+//passed to @|set| and @|get| to modify the properties of the
+//current figure, (e.g., the colormap).  So, for figure @|3|, for 
+//example, you can use @|get(3,'colormap')| to retrieve the colormap
+//for the current figure.
 //!
 ArrayVector HFigureFunction(int nargout,const ArrayVector& arg) {
   if (arg.size() == 0) {
@@ -409,6 +425,7 @@ ArrayVector HSetFunction(int nargout, const ArrayVector& arg) {
   fp->UpdateState();
   if (!fp->IsType("figure") && !fp->IsType("uicontrol")) {
     HandleFigure *fig = fp->GetParentFigure();
+    fig->UpdateState();
     fig->Repaint();
   }
   return ArrayVector();
@@ -503,7 +520,24 @@ unsigned GenericConstructor(HandleObject* fp, const ArrayVector& arg,
 ArrayVector HLineFunction(int nargout, const ArrayVector& arg) {
   return singleArrayVector(Array::uint32Constructor(GenericConstructor(new HandleLineSeries,arg)));
 }
-  
+
+//!
+//@Module HCONTOUR Create a contour object
+//@@Section HANDLE
+//@@Usage
+//Creates a contour object and parents it to the current axis.  The
+//syntax for its use is 
+//@[
+//  handle = hcontour(property,value,property,value,...)
+//@]
+//where @|property| and @|value| are set.  The handle ID for the
+//resulting object is returned.  It is automatically added to
+//the children of the current axis.
+//!
+ArrayVector HContourFunction(int nargout, const ArrayVector& arg) {
+  return singleArrayVector(Array::uint32Constructor(GenericConstructor(new HandleContour,arg)));
+}
+
 //!
 //@Module UICONTROL Create a UI Control object
 //@@Section HANDLE
@@ -582,16 +616,92 @@ ArrayVector HSurfaceFunction(int nargout, const ArrayVector& arg) {
   return singleArrayVector(Array::uint32Constructor(GenericConstructor(new HandleSurface,arg)));
 }
 
+//!
+//@Module FIGRAISE Raise a Figure Window
+//@@Section HANDLE
+//@@Usage
+//Raises a figure window indicated by the figure number.  The syntax for
+//its use is
+//@[
+//  figraise(fignum)
+//@]
+//where @|fignum| is the number of the figure to raise.  The figure will
+//be raised to the top of the GUI stack (meaning that it we be visible).
+//Note that this function does not cause @|fignum| to become the current
+//figure, you must use the @|figure| command for that.
+//!
+ArrayVector FigRaiseFunction(int nargout, const ArrayVector& args) {
+  if (args.size() == 0)
+    CurrentWindow()->raise();
+  else {
+    int fignum = ArrayToInt32(args[0]);
+    if ((fignum >= 1) && (fignum < MAX_FIGS+1)) {
+      if (Hfigs[fignum-1])
+	Hfigs[fignum-1]->raise();
+      else {
+	Hfigs[fignum-1] = new HandleWindow(fignum-1);
+	Hfigs[fignum-1]->show();
+	Hfigs[fignum-1]->raise();
+      }
+    }
+  }
+  return ArrayVector();
+}
+
+//!
+//@Module FIGLOWER Lower a Figure Window
+//@@Section HANDLE
+//@@Usage
+//Lowers a figure window indicated by the figure number.  The syntax for
+//its use is
+//@[
+//  figlower(fignum)
+//@]
+//where @|fignum| is the number of the figure to lower.  The figure will
+//be lowerd to the bottom of the GUI stack (meaning that it we be behind other
+//windows).  Note that this function does not cause @|fignum| to 
+//become the current  figure, you must use the @|figure| command for that.
+//Similarly, if @|fignum| is the current figure, it will remain the current
+//figure (even though the figure is now behind others).
+//!
+ArrayVector FigLowerFunction(int nargout, const ArrayVector& args) {
+  if (args.size() == 0)
+    CurrentWindow()->lower();
+  else {
+    int fignum = ArrayToInt32(args[0]);
+    if ((fignum >= 1) && (fignum < MAX_FIGS+1)) {
+      if (Hfigs[fignum-1])
+	Hfigs[fignum-1]->lower();
+      else {
+	Hfigs[fignum-1] = new HandleWindow(fignum-1);
+	Hfigs[fignum-1]->show();
+	Hfigs[fignum-1]->lower();
+      }
+    }
+  }
+  return ArrayVector();
+}
+
 //!
 //@Module GCF Get Current Figure
 //@@Section HANDLE
 //@@Usage
-//Returns the handle for the current figure.  The syntax for its use
+//Returns the figure number for the current figure (which is also its handle,
+//and can be used to set properties of the current figure using @|set|).  
+//The syntax for its use
 //is
 //@[
-//  handle = gcf
+//  figure_number = gcf
 //@]
-//where @|handle| is the number of the active figure (also its handle).
+//where @|figure_number| is the number of the active figure (also the handle of
+//the figure).
+//
+//Note that figures have handles, just like axes, images, plots, etc.  However
+//the handles for figures match the figure number (while handles for other 
+//graphics objects tend to be large, somewhat arbitrary integers).  So, to 
+//retrieve the colormap of the current figure, you could 
+//use @|get(gcf,'colormap')|, or to obtain the colormap for figure 3, 
+//use @|get(3,'colormap')|.
 //!
 ArrayVector HGCFFunction(int nargout, const ArrayVector& arg) {
   if (HcurrentFig == -1)
@@ -599,6 +709,8 @@ ArrayVector HGCFFunction(int nargout, const ArrayVector& arg) {
   return singleArrayVector(Array::uint32Constructor(HcurrentFig+1));
 }
 
+
+
 //!
 //@Module GCA Get Current Axis
 //@@Section HANDLE
@@ -687,6 +799,8 @@ bool PrintBaseFigure(HandleWindow* g, std::string filename,
     QPrinter prnt;
     if (type == "PDF")
       prnt.setOutputFormat(QPrinter::PdfFormat);
+    else
+      prnt.setOutputFormat(QPrinter::PostScriptFormat);
     prnt.setOutputFileName(filename.c_str());
     QPainter pnt(&prnt);
     QTRenderEngine gc(&pnt,0,0,g->width(),g->height());
@@ -914,344 +1028,6 @@ ArrayVector HPointFunction(int nargout, const ArrayVector& arg) {
   return singleArrayVector(retval);
 }
 
-// int refcount = 0;
-// extern int DataMakeCount;
-// // If the argument vector is numeric, we can
-// ArrayVector HDemoFunction(int nargout, const ArrayVector& arg, Interpreter *eval) {
-//   if (arg.size() == 0) return ArrayVector();
-//   int runtype = ArrayToInt32(arg[0]);
-//   Array B(FM_FLOAT,Dimensions(500,500));
-//   if (runtype == 0) {
-//     // Fastest possible run time 
-//     float *dp = (float *) B.getReadWriteDataPointer();
-//     for (int j=1;j<500;j++) {
-//       for (int k=1;k<500;k++) {
-// 	dp[j+500*(k-1)] = fabs(j-k)+1;
-//       }
-//     }
-//   } else if (runtype == 1) {
-//     // Current operational mode
-//     float *dp = (float *) B.getReadWriteDataPointer();
-//     Array K(FM_INT32,Dimensions(1,1));
-//     Array J(FM_INT32,Dimensions(1,1));
-//     for (int j=1;j<500;j++) {
-//       ((int32 *) J.getReadWriteDataPointer())[0] = j;
-//       for (int k=1;k<500;k++) {
-// 	((int32 *) K.getReadWriteDataPointer())[0] = k;
-// 	ArrayVector p;
-// 	p.push_back(J);
-// 	p.push_back(K);
-// 	Array c(Array::floatConstructor(fabs(j-k)+1));
-// 	B.setNDimSubset(p,c);
-//       } 
-//     } 
-//   } else if (runtype == 2) {
-//     // Reasonable operational mode
-//     float *dp = (float *) B.getReadWriteDataPointer();
-//     Array K(FM_INT32,Dimensions(1,1));
-//     Array J(FM_INT32,Dimensions(1,1));
-//     for (int j=1;j<500;j++) {
-//       ((int32 *) J.getReadWriteDataPointer())[0] = j;
-//       for (int k=1;k<500;k++) {
-// 	((int32 *) K.getReadWriteDataPointer())[0] = k;
-// 	int jval = ArrayToInt32(J);
-// 	int kval = ArrayToInt32(K);
-// 	((float *) B.getReadWriteDataPointer())[jval+500*(kval-1)] = fabs(jval-kval)+1;
-//       }
-//     }
-//   } else if (runtype == 3) {
-//     // Reasonable operational mode
-//     float *dp = (float *) B.getReadWriteDataPointer();
-//     Array K(FM_INT32,Dimensions(1,1));
-//     Array J(FM_INT32,Dimensions(1,1));
-//     for (int j=1;j<500;j++) {
-//       ((int32 *) J.getReadWriteDataPointer())[0] = j;
-//       for (int k=1;k<500;k++) {
-// 	((int32 *) K.getReadWriteDataPointer())[0] = k;
-// 	((float *) B.getReadWriteDataPointer())[j+500*(k-1)] = fabs(j-k)+1;
-//       }
-//     }
-//   } else if (runtype == 4) {
-//     // Reasonable operational mode
-//     float *dp = (float *) B.getReadWriteDataPointer();
-//     Array K(FM_INT32,Dimensions(1,1));
-//     Array J(FM_INT32,Dimensions(1,1));
-//     for (int j=1;j<500;j++) {
-//       ((int32 *) J.getReadWriteDataPointer())[0] = j;
-//       int jval = ArrayToInt32(J);
-//       for (int k=1;k<500;k++) {
-// 	((int32 *) K.getReadWriteDataPointer())[0] = k;
-// 	int kval = ArrayToInt32(K);
-// 	((float *) B.getReadWriteDataPointer())[jval+500*(kval-1)] = fabs(jval-kval)+1;
-//       }
-//     }
-//   } else if (runtype == 5) {
-//     // Try to create a large vector, and page through it using getVectorSubset
-//     Array I(Array::int32RangeConstructor(1,1,100000,false));
-//     for (int m=0;m<100000;m++) {
-//       Array M(Array::int32Constructor(m+1));
-//       Array G(I.getVectorSubset(M));
-//     }
-//   } else if (runtype == 6) {
-//     // Try to create a large vector, simulate page through it bypassing getVectorSubset
-//     // The time in this loop is spent as follows:
-//     //8343     13.5247  FreeMat                  Data::Data(Class, Dimensions const&, void*, bool, std::vector<std::string, std::allocator<std::string> > const&, std::vector<std::string, std::allocator<std::string> >)
-//     //7434     12.0512  FreeMat                  Dimensions::getElementCount() const
-//     //7238     11.7334  FreeMat                  std::vector<std::string, std::allocator<std::string> >::~vector()
-//     //6621     10.7332  FreeMat                  Array::Array(Class, Dimensions const&, void*, bool, std::vector<std::string, std::allocator<std::string> > const&, std::vector<std::string, std::allocator<std::string> > const&)
-//     //4924      7.9822  FreeMat                  Array::int32Constructor(int)
-//     //4145      6.7194  FreeMat                  Data::~Data()
-//     //3324      5.3885  FreeMat                  Data::refreshDimensionCache()
-//     //2529      4.0997  FreeMat                  Array::~Array()
-//     //2052      3.3265  FreeMat                  Malloc(int)
-//     //2036      3.3005  FreeMat                  .plt
-//     //1906      3.0898  FreeMat                  HDemoFunction(int, std::vector<Array, std::allocator<Array> > const&, Interpreter*)
-//     //1563      2.5338  FreeMat                  Array::allocateArray(Class, unsigned int, std::vector<std::string, std::allocator<std::string> > const&)
-//     //
-//     Array I(Array::int32RangeConstructor(1,1,100000,false));
-//     for (int m=0;m<1000000;m++) {
-//       Array M(Array::int32Constructor(m+1));
-//     }
-//   } else if (runtype == 7) {
-//     // Create a large vector, simulate page through it, without int32Constructor
-//     Array I(Array::int32RangeConstructor(1,1,100000,false));
-//     Array M(Array::int32Constructor(0));
-//     for (int m=0;m<100000;m++) {
-//       int32 *M_p = (int32*) M.getReadWriteDataPointer();
-//       M_p[0] = m+1;
-//       Array G(I.getVectorSubset(M));
-//     }
-//   } else if (runtype == 8) {
-//     // Try to create a large vector, simulate page through it bypassing getVectorSubset
-//     Array I(Array::int32RangeConstructor(1,1,100000,false));
-//     for (int m=0;m<100000;m++) {
-//       int32 *mp = (int32*) malloc(sizeof(int32));
-//       int32 *gp = (int32*) malloc(sizeof(int32));
-//       *mp = m+1;
-//       *gp = m+1;
-//       Array M(FM_INT32,Dimensions(1,1),mp);
-//       Array G(FM_INT32,Dimensions(1,1),gp);
-//     }
-//   } else if (runtype == 9) {
-//     // Create a large vector, simulate page through it, without int32Constructor
-//     Array I(Array::int32RangeConstructor(1,1,100000,false));
-//     Array M(Array::int32Constructor(0));
-//     for (int m=0;m<100000;m++) {
-//       int32 *M_p = (int32*) M.getReadWriteDataPointer();
-//       M_p[0] = m+1;
-//     }
-//   } else if (runtype == 10) {
-//     // This simulates an empty for loop without the penalty of getVectorSubset
-//     // It is still quite slow, and note because of getRWDP call (demo(9) requires
-//     // 5 ms to run, this one takes 237 ms.
-//     Scope *scope = eval->getContext()->getCurrentScope();
-//     Array I(Array::int32Constructor(0));
-//     for (int m=0;m<100000;m++) {
-//       int32 *I_p = (int32*) I.getReadWriteDataPointer();
-//       I_p[0] = m+1;
-//       scope->insertVariable("i",I);
-//     }
-//   } else if (runtype == 11) {
-//     // This simulates an empty for loop without the penalty of getVectorSubset
-//     // It is still quite slowly, and not because of getRWDP call (demo(9) requires
-//     // 5 ms to run, demo(10) takes 237 ms.  This version uses the interface 
-//     // provided by Context, instead of Scope.  It requires 253 ms.  So the time
-//     // is still dominated by the scope interface.  Clearly I need to revisit
-//     // the symbol table code.
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     for (int m=0;m<100000;m++) {
-//       int32 *I_p = (int32*) I.getReadWriteDataPointer();
-//       I_p[0] = m+1;
-//       context->insertVariable("i",I);
-//     }
-//   } else if (runtype == 12) {
-//     //
-//     // The symbol table code is not the problem.  The problem is that the
-//     // value semantics of assignment are the problem... So consider the
-//     // following: it executes in about 62 ms.  
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     for (int m=0;m<100000;m++) {
-//       Array *vp = context->lookupVariableLocally("i");
-//       int32 *I_p = (int32*) vp->getReadWriteDataPointer();
-//       I_p[0] = m+1;
-//     }
-//   } else if (runtype == 13) {
-//     //
-//     // The symbol table code is not the problem.  The problem is that the
-//     // value semantics of assignment are the problem... So consider the
-//     // following: it executes in about 30 ms (just the variable lookup time).
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<100000;m++) {
-//       Array *vp = context->lookupVariableLocally(name);
-//     }
-//   } else if (runtype == 14) {    
-//     //
-//     // In this version, we bypass the context again..  This gets run time
-//     // down to 7 ms.  
-//     //
-//     Context *context = eval->getContext();
-//     Scope *scope = context->getCurrentScope();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<100000;m++) {
-//       Array *vp = scope->lookupVariable(name);
-//     }
-//   } else if (runtype == 15) {
-//     // In this version, we bypass the context, but call RWDP - we are at the
-//     // target of 10 ms.
-//     Context *context = eval->getContext();
-//     Scope *scope = context->getCurrentScope();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<100000;m++) {
-//       Array *vp = scope->lookupVariable(name);
-//       ((int32*) vp->getReadWriteDataPointer())[0] = m+1;
-//     }
-//   } else if (runtype == 16) {
-//     B = Array::int32Constructor(DataMakeCount);
-//   } else if (runtype == 17) {
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<100000;m++) {
-//       Array *vp = context->lookupVariable(name);
-//     }
-//   } else if (runtype == 18) {
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<10000000;m++) {
-//       Array *vp = context->lookupVariable(name);
-//       context->insertVariable("j",*vp);
-//     }
-//   } else if (runtype == 19) {
-//     Context *context = eval->getContext();
-//     Scope *scope = context->getCurrentScope();
-//     Array I(Array::int32Constructor(0));
-//     scope->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<10000000;m++) {
-//       Array *vp = scope->lookupVariable(name);
-//       scope->insertVariable("j",*vp);
-//     }
-//   } else if (runtype == 20) {
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<10000000;m++) {
-//       Array *vp = context->lookupVariable(name);
-//       ArrayVector p(singleArrayVector(*vp));
-//       context->insertVariable("j",p[0]);
-//     }
-//   } else if (runtype == 21) {
-//     Context *context = eval->getContext();
-//     Array I(Array::int32Constructor(0));
-//     context->insertVariable("i",I);
-//     string name("i");
-//     for (int m=0;m<100000;m++) {
-//       Array J(I);
-//       Array K(I);
-//     }
-//   } else if (runtype == 22) {
-//     Array a(Array::int32Constructor(0));
-//     for (int m=0;m<10000000;m++) {
-//       Array b(a);
-//     }
-//   } else if (runtype == 23) {
-//     struct {
-//       int data[10];
-//     } a, b;
-//     for (int m=0;m<10000000;m++) {
-//       b = a;
-//     }
-//   } else if (runtype == 24) {
-//     class foo {
-//       int data[10];
-//     public:
-//       foo() {data[0] = 0; refcount++;}
-//       ~foo() {refcount--;}
-//     };
-    
-//     foo a;
-//     for (int m=0;m<10000000;m++) {
-//       foo b(a);
-//     }
-//   } else if (runtype == 25) {
-//     class foo {
-//       int data[10];
-//     public:
-//       foo() {data[0] = 0; refcount++;}
-//       ~foo() {refcount--;}
-//     };
-    
-//     foo *a; 
-//     for (int m=0;m<10000000;m++) {
-//       a = new foo;
-//       delete a;
-//     }
-//   } else if (runtype == 26) {
-//     Array A(FM_FLOAT,Dimensions(512,512));
-//     Array B(FM_FLOAT,Dimensions(512,512));
-//     Array I(Array::uint32Constructor(0));
-//     Array J(Array::uint32Constructor(0));
-//     for (int i=0;i<512;i++)
-//       for (int j=0;j<512;j++) {
-// 	((uint32*) I.getReadWriteDataPointer())[0] = i+1;
-// 	((uint32*) J.getReadWriteDataPointer())[0] = j+1;
-// 	ArrayVector T;
-// 	T.push_back(I);
-// 	T.push_back(J);
-// 	Array C(A.getNDimSubset(T));
-// 	B.setNDimSubset(T,C);
-//       }
-//   } else if (runtype == 27) {
-//     Array A(FM_FLOAT,Dimensions(512,512));
-//     Array B(FM_FLOAT,Dimensions(512,512));
-//     Array I(Array::uint32Constructor(0));
-//     Array J(Array::uint32Constructor(0));
-//     for (int i=0;i<512;i++)
-//       for (int j=0;j<512;j++) {
-// 	((uint32*) I.getReadWriteDataPointer())[0] = i+1;
-// 	((uint32*) J.getReadWriteDataPointer())[0] = j+1;
-// 	ArrayVector T;
-// 	T.push_back(I);
-// 	T.push_back(J);
-// 	Array C(A.getNDimSubset(T));
-// 	ArrayVector R;
-// 	R.push_back(J);
-// 	R.push_back(I);
-// 	B.setNDimSubset(R,C);
-//       }
-//   } else if (runtype == 28) {
-//     Array A(FM_FLOAT,Dimensions(512,512));
-//     Array B(FM_FLOAT,Dimensions(512,512));
-//     Array I(Array::uint32Constructor(0));
-//     Array J(Array::uint32Constructor(0));
-//     for (int i=0;i<512;i++)
-//       for (int j=0;j<512;j++) {
-// 	((uint32*) I.getReadWriteDataPointer())[0] = i+1;
-// 	((uint32*) J.getReadWriteDataPointer())[0] = j+1;
-// 	ArrayVector T;
-// 	T.push_back(I);
-// 	T.push_back(J);
-// 	Array C(A.getNDimSubset(T));
-//       }
-//   }
-//   return singleArrayVector(B);
-// }
-
-
 //!
 //@Module IS2DVIEW Test Axes For 2D View
 //@@Section HANDLE
@@ -1274,6 +1050,7 @@ ArrayVector HIs2DViewFunction(int nargout, const ArrayVector& arg) {
   return singleArrayVector(Array::logicalConstructor(axis->Is2DView()));
 }
 
+#if 0
 class contour_point {
 public:
   double x;
@@ -1428,6 +1205,7 @@ ArrayVector ContourCFunction(int nargout, const ArrayVector& arg) {
   }
   return ArrayVector() << out;
 }
+#endif 
 
 void LoadHandleGraphicsFunctions(Context* context) {
   context->addGfxFunction("is2dview",HIs2DViewFunction,1,1,"x",NULL);
@@ -1435,6 +1213,7 @@ void LoadHandleGraphicsFunctions(Context* context) {
   context->addGfxFunction("hline",HLineFunction,-1,1,NULL);
   context->addGfxFunction("htext",HTextFunction,-1,1,NULL);
   context->addGfxFunction("himage",HImageFunction,-1,1,NULL);
+  context->addGfxFunction("hcontour",HContourFunction,-1,1,NULL);
   context->addGfxFunction("surface",HSurfaceFunction,-1,1,NULL);
   context->addGfxFunction("set",HSetFunction,-1,0,NULL);
   context->addGfxFunction("get",HGetFunction,2,1,"handle","propname",NULL);
@@ -1448,7 +1227,9 @@ void LoadHandleGraphicsFunctions(Context* context) {
   context->addGfxFunction("copy",HCopyFunction,0,0,NULL);
   context->addGfxFunction("hpoint",HPointFunction,0,1,NULL);
   context->addGfxFunction("drawnow",DrawNowFunction,0,0,NULL);
-  context->addFunction("contourc",ContourCFunction,2,1,"z","v",NULL);
+  context->addGfxFunction("figraise",FigRaiseFunction,1,0,"handle",NULL);
+  context->addGfxFunction("figlower",FigLowerFunction,1,0,"handle",NULL);
+  //  context->addFunction("contourc",ContourCFunction,2,1,"z","v",NULL);
   //  context->addSpecialFunction("demo",HDemoFunction,1,1,NULL);
   InitializeHandleGraphics();
 };
