@@ -19,6 +19,7 @@
 #include "QTRenderEngine.hpp"
 #include <math.h>
 #include <algorithm>
+#include <QDebug>
 
 bool operator<(const quad3d& a, const quad3d& b) {
   return (a.meanz < b.meanz);
@@ -292,6 +293,7 @@ void QTRenderEngine::project(double left, double right,
 void QTRenderEngine::viewport(double x0, double y0, double width, double height) {
   viewp[0] = (int)x0; viewp[1] = (int)y0; viewp[2] = (int)width; viewp[3] = (int)height;
   pnt->setClipRect((int)x0,(int)(m_height-(y0+height)),(int)width,(int)height);
+  //  qDebug() << "clip " << x0 << "," << (int)(m_height-(y0+height)) << "," << (int)width << "," << (int)height;
 }
 
 void QTRenderEngine::quad(double x1, double y1, double z1,
@@ -563,12 +565,61 @@ void QTRenderEngine::drawImage(double x1, double y1, double x2, double y2,
 			       QImage pic) {
   QPointF pt(Map(x1,y1,0));
   pt.setY(pt.y()-pic.height());
+  //  qDebug() << "image draw at " << pt << "," << pic.size();
   pnt->drawImage(pt,pic);
 }
-  
+
+QPainterPath QTRenderEngine::quadToPoly(double x1, double y1, double z1,
+					double x2, double y2, double z2,
+					double x3, double y3, double z3,
+					double x4, double y4, double z4) {
+  QPainterPath path;
+  path.moveTo(Map(x1,y1,z1));
+  path.lineTo(Map(x2,y2,z2));
+  path.lineTo(Map(x3,y3,z3));
+  path.lineTo(Map(x4,y4,z4));
+  path.closeSubpath();
+  return path;
+}
+
+void QTRenderEngine::setClipBox(std::vector<double> limits) {
+  pnt->setClipPath(quadToPoly( limits[0], limits[2], limits[4],
+			       limits[1], limits[2], limits[4],
+			       limits[1], limits[3], limits[4],
+			       limits[0], limits[3], limits[4]), 
+		   Qt::ReplaceClip);
+  pnt->setClipPath(quadToPoly( limits[0], limits[2], limits[5],
+			       limits[0], limits[3], limits[5],
+			       limits[1], limits[3], limits[5],
+			       limits[1], limits[2], limits[5]),
+		   Qt::UniteClip);
+  pnt->setClipPath(quadToPoly( limits[0], limits[2], limits[4],
+			       limits[0], limits[3], limits[4],
+			       limits[0], limits[3], limits[5],
+			       limits[0], limits[2], limits[5]),
+		   Qt::UniteClip);
+  pnt->setClipPath(quadToPoly( limits[1], limits[2], limits[4],
+			       limits[1], limits[2], limits[5],
+			       limits[1], limits[3], limits[5],
+			       limits[1], limits[3], limits[4]),
+		   Qt::UniteClip);
+  pnt->setClipPath(quadToPoly( limits[0], limits[2], limits[4],
+			       limits[0], limits[2], limits[5],
+			       limits[1], limits[2], limits[5],
+			       limits[1], limits[2], limits[4]),
+		   Qt::UniteClip);
+  pnt->setClipPath(quadToPoly( limits[0], limits[3], limits[4],
+			       limits[1], limits[3], limits[4],
+			       limits[1], limits[3], limits[5],
+			       limits[0], limits[3], limits[5]),
+		   Qt::UniteClip);
+  //  pnt->setClipPath(path);
+}
 
 void QTRenderEngine::quadStrips(std::vector<std::vector<cpoint> > faces, bool flatfaces,
 				std::vector<std::vector<cpoint> > edges, bool flatedges) {
+  //  qDebug() << "Faces " << faces.size();
+  //  qDebug() << "Edges " << edges.size();
   std::vector<quad3d> mapqds(MapQuads(faces,edges));
   std::sort(mapqds.begin(),mapqds.end());
   for (int i=0;i<mapqds.size();i++) {
@@ -577,6 +628,20 @@ void QTRenderEngine::quadStrips(std::vector<std::vector<cpoint> > faces, bool fl
     poly.push_back(QPointF(mapqds[i].pts[1].x,mapqds[i].pts[1].y));
     poly.push_back(QPointF(mapqds[i].pts[3].x,mapqds[i].pts[3].y));
     poly.push_back(QPointF(mapqds[i].pts[2].x,mapqds[i].pts[2].y));
+    
+//     qDebug() << "Brush " << (int)(mapqds[i].r*255) << "," 
+// 	     << (int)(mapqds[i].g*255)
+// 	     << (int)(mapqds[i].b*255)
+// 	     << (int)(mapqds[i].a*255);
+//     qDebug() << "Pen " << (int)(mapqds[i].er*255) << "," 
+// 	     << (int)(mapqds[i].eg*255)
+// 	     << (int)(mapqds[i].eb*255)
+// 	     << (int)(mapqds[i].ea*255);
+//     qDebug() << "Point " << mapqds[i].pts[0].x << "," << mapqds[i].pts[0].y;
+//     qDebug() << "Point " << mapqds[i].pts[1].x << "," << mapqds[i].pts[1].y;
+//     qDebug() << "Point " << mapqds[i].pts[2].x << "," << mapqds[i].pts[2].y;
+//     qDebug() << "Point " << mapqds[i].pts[3].x << "," << mapqds[i].pts[3].y;
+
     pnt->setBrush(QColor((int)(mapqds[i].r*255),
 			 (int)(mapqds[i].g*255),
 			 (int)(mapqds[i].b*255),
